@@ -1,6 +1,8 @@
 import ast
 import glob
+import logging
 import os
+import re
 import shutil
 import subprocess
 
@@ -26,19 +28,18 @@ class BarCodeReader:
             os.makedirs(cache_dir, exist_ok=True)
             shutil.move(res[0], cache_dir)
         else:
-            print("Use local jar file.")
+            logging.debug("Use local jar file.")
             download_url = os.path.join(jar_url, jar_filename)
             save_path = os.path.join(cache_dir, jar_filename)
             if not os.path.exists(save_path):
                 get_file(jar_filename, download_url, cache_dir)
-                print("Download completed.")
+                logging.debug("Download completed.")
             self.lib_path = save_path
 
     def decode(self, filename_pattern):
         filenames = glob.glob(os.path.abspath(filename_pattern))
         if len(filenames) == 0:
-            print("File not found!")
-            results = None
+            raise FileNotFoundError
 
         elif len(filenames) == 1:
             results = self._decode(filenames[0].replace('\\', '/'))
@@ -59,11 +60,15 @@ class BarCodeReader:
             array = array[:, :, ::-1]
         cv.imwrite(filename, array)
 
-        return self.decode(filename)
+        result = self.decode(filename)
+
+        os.remove(filename)
+
+        return result
 
     def _decode(self, filename):
         cmd = ' '.join(
-            [self.command, self.lib_path, 'file:///' + filename, '--multi'])
+            [self.command, self.lib_path, 'file:///' + filename, '--multi', '--try_harder'])
         (stdout, _) = subprocess.Popen(cmd,
                                        stdout=subprocess.PIPE,
                                        # universal_newlines=True,
@@ -111,9 +116,11 @@ class BarCodeReader:
 
             result['raw'] = b'\n'.join(lines[raw_index + 1:parsed_index])
             result['parsed'] = b'\n'.join(lines[parsed_index + 1:points_index])
+
+            points_num = int(re.search(r"(?<=Found )\d?", lines[points_index].decode()).group())
             result['points'] = [
                 ast.literal_eval(line.split(b": ")[1].decode())
-                for line in lines[points_index + 1:-1]
+                for line in lines[points_index + 1:points_index + 1 + points_num]
             ]
 
         return result
